'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ITEM_KEYS = exports.ITEM_TYPES = undefined;
exports.getPaginationModel = getPaginationModel;

var _ultimatePaginationConstants = require('./ultimate-pagination-constants');

Object.defineProperty(exports, 'ITEM_TYPES', {
  enumerable: true,
  get: function get() {
    return _ultimatePaginationConstants.ITEM_TYPES;
  }
});
Object.defineProperty(exports, 'ITEM_KEYS', {
  enumerable: true,
  get: function get() {
    return _ultimatePaginationConstants.ITEM_KEYS;
  }
});

var _ultimatePaginationUtils = require('./ultimate-pagination-utils');

var _ultimatePaginationItemFactories = require('./ultimate-pagination-item-factories');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function getPaginationModel(options) {
  var currentPage = options.currentPage;
  var totalPages = options.totalPages;

  var paginationModel = [];
  var createPage = (0, _ultimatePaginationItemFactories.createPageFunctionFactory)(options);

  // Calculate group of central pages
  var mainPagesStart = Math.max(currentPage - 1, 3) - Math.max(0, currentPage + 3 - totalPages);
  var mainPagesEnd = Math.min(currentPage + 1, totalPages - 2) + Math.max(0, 4 - currentPage);
  var mainPages = (0, _ultimatePaginationUtils.createRange)(mainPagesStart, mainPagesEnd).map(createPage);

  paginationModel.push((0, _ultimatePaginationItemFactories.createFirstPageLink)(options));
  paginationModel.push((0, _ultimatePaginationItemFactories.createPreviousPageLink)(options));

  // Always add the first page
  paginationModel.push(createPage(1));

  // Show '...' or second page between the last page and main pages group if needed
  if (mainPagesStart > 3) {
    paginationModel.push((0, _ultimatePaginationItemFactories.createFirstEllipsis)(mainPagesStart - 1));
  } else {
    paginationModel.push(createPage(2));
  }

  // Add pages +/- from the current page
  paginationModel.push.apply(paginationModel, _toConsumableArray(mainPages));

  // Show '...' or penult page between main pages group and the last page if needed
  if (mainPagesEnd < totalPages - 2) {
    paginationModel.push((0, _ultimatePaginationItemFactories.createSecondEllipsis)(mainPagesEnd + 1));
  } else {
    paginationModel.push(createPage(totalPages - 1));
  }

  // Always add the last page
  paginationModel.push(createPage(totalPages));
  paginationModel.push((0, _ultimatePaginationItemFactories.createNextPageLink)(options));
  paginationModel.push((0, _ultimatePaginationItemFactories.createLastPageLink)(options));

  return paginationModel;
}